"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import getbyorgbyrepobranchesop as models_getbyorgbyrepobranchesop
from mesa_sdk.types import BaseModel
from typing import Optional


class GetByOrgByRepoBranchesInternalServerErrorData(BaseModel):
    error: (
        models_getbyorgbyrepobranchesop.GetByOrgByRepoBranchesInternalServerErrorError
    )


@dataclass(unsafe_hash=True)
class GetByOrgByRepoBranchesInternalServerError(MesaError):
    r"""Internal error"""

    data: GetByOrgByRepoBranchesInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoBranchesInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoBranchesConflictErrorData(BaseModel):
    error: models_getbyorgbyrepobranchesop.GetByOrgByRepoBranchesConflictError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoBranchesConflictError(MesaError):
    r"""Conflict"""

    data: GetByOrgByRepoBranchesConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoBranchesConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoBranchesNotAcceptableErrorData(BaseModel):
    error: models_getbyorgbyrepobranchesop.GetByOrgByRepoBranchesNotAcceptableError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoBranchesNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: GetByOrgByRepoBranchesNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoBranchesNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoBranchesNotFoundErrorData(BaseModel):
    error: models_getbyorgbyrepobranchesop.GetByOrgByRepoBranchesNotFoundError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoBranchesNotFoundError(MesaError):
    r"""Not found"""

    data: GetByOrgByRepoBranchesNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoBranchesNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoBranchesForbiddenErrorData(BaseModel):
    error: models_getbyorgbyrepobranchesop.GetByOrgByRepoBranchesForbiddenError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoBranchesForbiddenError(MesaError):
    r"""Forbidden"""

    data: GetByOrgByRepoBranchesForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoBranchesForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoBranchesUnauthorizedErrorData(BaseModel):
    error: models_getbyorgbyrepobranchesop.GetByOrgByRepoBranchesUnauthorizedError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoBranchesUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: GetByOrgByRepoBranchesUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoBranchesUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoBranchesBadRequestErrorData(BaseModel):
    error: models_getbyorgbyrepobranchesop.GetByOrgByRepoBranchesBadRequestError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoBranchesBadRequestError(MesaError):
    r"""Invalid request"""

    data: GetByOrgByRepoBranchesBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoBranchesBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import postbyorgbyrepocommitsop as models_postbyorgbyrepocommitsop
from mesa_sdk.types import BaseModel
from typing import Optional


class PostByOrgByRepoCommitsInternalServerErrorData(BaseModel):
    error: (
        models_postbyorgbyrepocommitsop.PostByOrgByRepoCommitsInternalServerErrorError
    )


@dataclass(unsafe_hash=True)
class PostByOrgByRepoCommitsInternalServerError(MesaError):
    r"""Internal error"""

    data: PostByOrgByRepoCommitsInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgByRepoCommitsInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgByRepoCommitsConflictErrorData(BaseModel):
    error: models_postbyorgbyrepocommitsop.PostByOrgByRepoCommitsConflictError


@dataclass(unsafe_hash=True)
class PostByOrgByRepoCommitsConflictError(MesaError):
    r"""Conflict"""

    data: PostByOrgByRepoCommitsConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgByRepoCommitsConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgByRepoCommitsNotAcceptableErrorData(BaseModel):
    error: models_postbyorgbyrepocommitsop.PostByOrgByRepoCommitsNotAcceptableError


@dataclass(unsafe_hash=True)
class PostByOrgByRepoCommitsNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: PostByOrgByRepoCommitsNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgByRepoCommitsNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgByRepoCommitsNotFoundErrorData(BaseModel):
    error: models_postbyorgbyrepocommitsop.PostByOrgByRepoCommitsNotFoundError


@dataclass(unsafe_hash=True)
class PostByOrgByRepoCommitsNotFoundError(MesaError):
    r"""Not found"""

    data: PostByOrgByRepoCommitsNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgByRepoCommitsNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgByRepoCommitsForbiddenErrorData(BaseModel):
    error: models_postbyorgbyrepocommitsop.PostByOrgByRepoCommitsForbiddenError


@dataclass(unsafe_hash=True)
class PostByOrgByRepoCommitsForbiddenError(MesaError):
    r"""Forbidden"""

    data: PostByOrgByRepoCommitsForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgByRepoCommitsForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgByRepoCommitsUnauthorizedErrorData(BaseModel):
    error: models_postbyorgbyrepocommitsop.PostByOrgByRepoCommitsUnauthorizedError


@dataclass(unsafe_hash=True)
class PostByOrgByRepoCommitsUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: PostByOrgByRepoCommitsUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgByRepoCommitsUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgByRepoCommitsBadRequestErrorData(BaseModel):
    error: models_postbyorgbyrepocommitsop.PostByOrgByRepoCommitsBadRequestError


@dataclass(unsafe_hash=True)
class PostByOrgByRepoCommitsBadRequestError(MesaError):
    r"""Invalid request"""

    data: PostByOrgByRepoCommitsBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgByRepoCommitsBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import (
    getbyorgbyrepoagentblameop as models_getbyorgbyrepoagentblameop,
)
from mesa_sdk.types import BaseModel
from typing import Optional


class GetByOrgByRepoAgentblameInternalServerErrorData(BaseModel):
    error: models_getbyorgbyrepoagentblameop.GetByOrgByRepoAgentblameInternalServerErrorError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoAgentblameInternalServerError(MesaError):
    r"""Internal error"""

    data: GetByOrgByRepoAgentblameInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoAgentblameInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoAgentblameConflictErrorData(BaseModel):
    error: models_getbyorgbyrepoagentblameop.GetByOrgByRepoAgentblameConflictError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoAgentblameConflictError(MesaError):
    r"""Conflict"""

    data: GetByOrgByRepoAgentblameConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoAgentblameConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoAgentblameNotAcceptableErrorData(BaseModel):
    error: models_getbyorgbyrepoagentblameop.GetByOrgByRepoAgentblameNotAcceptableError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoAgentblameNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: GetByOrgByRepoAgentblameNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoAgentblameNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoAgentblameNotFoundErrorData(BaseModel):
    error: models_getbyorgbyrepoagentblameop.GetByOrgByRepoAgentblameNotFoundError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoAgentblameNotFoundError(MesaError):
    r"""Not found"""

    data: GetByOrgByRepoAgentblameNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoAgentblameNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoAgentblameForbiddenErrorData(BaseModel):
    error: models_getbyorgbyrepoagentblameop.GetByOrgByRepoAgentblameForbiddenError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoAgentblameForbiddenError(MesaError):
    r"""Forbidden"""

    data: GetByOrgByRepoAgentblameForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoAgentblameForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoAgentblameUnauthorizedErrorData(BaseModel):
    error: models_getbyorgbyrepoagentblameop.GetByOrgByRepoAgentblameUnauthorizedError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoAgentblameUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: GetByOrgByRepoAgentblameUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoAgentblameUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoAgentblameBadRequestErrorData(BaseModel):
    error: models_getbyorgbyrepoagentblameop.GetByOrgByRepoAgentblameBadRequestError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoAgentblameBadRequestError(MesaError):
    r"""Invalid request"""

    data: GetByOrgByRepoAgentblameBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoAgentblameBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from mesa_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from mesa_sdk.utils import FieldMetadata, PathParamMetadata, validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetByOrgByRepoRequestTypedDict(TypedDict):
    org: str
    repo: str


class GetByOrgByRepoRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    repo: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class GetByOrgByRepoInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


GetByOrgByRepoResolutionStrategy = Literal["none",]
r"""Conflict resolution strategy. \"none\" means sync will fail on conflicts."""


class GetByOrgByRepoAutosyncTypedDict(TypedDict):
    period: float
    r"""Polling period in seconds"""
    resolution_strategy: GetByOrgByRepoResolutionStrategy
    r"""Conflict resolution strategy. \"none\" means sync will fail on conflicts."""
    type: Literal["poll"]


class GetByOrgByRepoAutosync(BaseModel):
    period: float
    r"""Polling period in seconds"""

    resolution_strategy: GetByOrgByRepoResolutionStrategy
    r"""Conflict resolution strategy. \"none\" means sync will fail on conflicts."""

    type: Annotated[
        Annotated[Literal["poll"], AfterValidator(validate_const("poll"))],
        pydantic.Field(alias="type"),
    ] = "poll"


class GetByOrgByRepoUpstreamTypedDict(TypedDict):
    uri: str
    r"""URL of the upstream repository"""
    autosync: Nullable[GetByOrgByRepoAutosyncTypedDict]
    r"""Automatic sync configuration, if enabled"""
    last_sync_attempt: Nullable[datetime]
    r"""Timestamp of the last sync attempt"""
    last_sync_success: Nullable[datetime]
    r"""Timestamp of the last successful sync"""
    last_sync_error: Nullable[str]
    r"""Error message from the last failed sync attempt"""


class GetByOrgByRepoUpstream(BaseModel):
    uri: str
    r"""URL of the upstream repository"""

    autosync: Nullable[GetByOrgByRepoAutosync]
    r"""Automatic sync configuration, if enabled"""

    last_sync_attempt: Nullable[datetime]
    r"""Timestamp of the last sync attempt"""

    last_sync_success: Nullable[datetime]
    r"""Timestamp of the last successful sync"""

    last_sync_error: Nullable[str]
    r"""Error message from the last failed sync attempt"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetByOrgByRepoResponseTypedDict(TypedDict):
    r"""Repository"""

    id: str
    org: str
    name: str
    default_branch: str
    size_bytes: float
    last_push_at: Nullable[str]
    created_at: str
    upstream: Nullable[GetByOrgByRepoUpstreamTypedDict]
    r"""Optionally add an upstream repository. You can configure automatic syncing from the upstream repository."""


class GetByOrgByRepoResponse(BaseModel):
    r"""Repository"""

    id: str

    org: str

    name: str

    default_branch: str

    size_bytes: float

    last_push_at: Nullable[str]

    created_at: str

    upstream: Nullable[GetByOrgByRepoUpstream]
    r"""Optionally add an upstream repository. You can configure automatic syncing from the upstream repository."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from mesa_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from mesa_sdk.utils import FieldMetadata, PathParamMetadata, validate_const
import pydantic
from pydantic import Field, model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class GetByOrgByRepoSyncRequestTypedDict(TypedDict):
    org: str
    repo: str


class GetByOrgByRepoSyncRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    repo: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class GetByOrgByRepoSyncInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoSyncInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoSyncConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoSyncConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoSyncNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoSyncNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoSyncNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoSyncNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoSyncForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoSyncForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoSyncUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoSyncUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoSyncBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoSyncBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class StatusErrorTypedDict(TypedDict):
    r"""The last sync failed with an error."""

    message: str
    r"""Error message from the last failed sync attempt"""
    type: Literal["error"]


class StatusError(BaseModel):
    r"""The last sync failed with an error."""

    message: str
    r"""Error message from the last failed sync attempt"""

    type: Annotated[
        Annotated[Literal["error"], AfterValidator(validate_const("error"))],
        pydantic.Field(alias="type"),
    ] = "error"


class StatusOkTypedDict(TypedDict):
    r"""The last sync was successful."""

    type: Literal["ok"]


class StatusOk(BaseModel):
    r"""The last sync was successful."""

    type: Annotated[
        Annotated[Literal["ok"], AfterValidator(validate_const("ok"))],
        pydantic.Field(alias="type"),
    ] = "ok"


StatusTypedDict = TypeAliasType(
    "StatusTypedDict", Union[StatusOkTypedDict, StatusErrorTypedDict]
)
r"""What the status of the last sync was."""


Status = Annotated[Union[StatusOk, StatusError], Field(discriminator="type")]
r"""What the status of the last sync was."""


class GetByOrgByRepoSyncResponseTypedDict(TypedDict):
    r"""Sync status"""

    last_sync_attempt: Nullable[datetime]
    r"""Timestamp of the last sync attempt"""
    last_sync_success: Nullable[datetime]
    r"""Timestamp of the last successful sync"""
    status: StatusTypedDict
    r"""What the status of the last sync was."""


class GetByOrgByRepoSyncResponse(BaseModel):
    r"""Sync status"""

    last_sync_attempt: Nullable[datetime]
    r"""Timestamp of the last sync attempt"""

    last_sync_success: Nullable[datetime]
    r"""Timestamp of the last successful sync"""

    status: Status
    r"""What the status of the last sync was."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import (
    postbyorgbyrepowebhooksop as models_postbyorgbyrepowebhooksop,
)
from mesa_sdk.types import BaseModel
from typing import Optional


class PostByOrgByRepoWebhooksInternalServerErrorData(BaseModel):
    error: (
        models_postbyorgbyrepowebhooksop.PostByOrgByRepoWebhooksInternalServerErrorError
    )


@dataclass(unsafe_hash=True)
class PostByOrgByRepoWebhooksInternalServerError(MesaError):
    r"""Internal error"""

    data: PostByOrgByRepoWebhooksInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgByRepoWebhooksInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgByRepoWebhooksConflictErrorData(BaseModel):
    error: models_postbyorgbyrepowebhooksop.PostByOrgByRepoWebhooksConflictError


@dataclass(unsafe_hash=True)
class PostByOrgByRepoWebhooksConflictError(MesaError):
    r"""Conflict"""

    data: PostByOrgByRepoWebhooksConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgByRepoWebhooksConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgByRepoWebhooksNotAcceptableErrorData(BaseModel):
    error: models_postbyorgbyrepowebhooksop.PostByOrgByRepoWebhooksNotAcceptableError


@dataclass(unsafe_hash=True)
class PostByOrgByRepoWebhooksNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: PostByOrgByRepoWebhooksNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgByRepoWebhooksNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgByRepoWebhooksNotFoundErrorData(BaseModel):
    error: models_postbyorgbyrepowebhooksop.PostByOrgByRepoWebhooksNotFoundError


@dataclass(unsafe_hash=True)
class PostByOrgByRepoWebhooksNotFoundError(MesaError):
    r"""Not found"""

    data: PostByOrgByRepoWebhooksNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgByRepoWebhooksNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgByRepoWebhooksForbiddenErrorData(BaseModel):
    error: models_postbyorgbyrepowebhooksop.PostByOrgByRepoWebhooksForbiddenError


@dataclass(unsafe_hash=True)
class PostByOrgByRepoWebhooksForbiddenError(MesaError):
    r"""Forbidden"""

    data: PostByOrgByRepoWebhooksForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgByRepoWebhooksForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgByRepoWebhooksUnauthorizedErrorData(BaseModel):
    error: models_postbyorgbyrepowebhooksop.PostByOrgByRepoWebhooksUnauthorizedError


@dataclass(unsafe_hash=True)
class PostByOrgByRepoWebhooksUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: PostByOrgByRepoWebhooksUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgByRepoWebhooksUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgByRepoWebhooksBadRequestErrorData(BaseModel):
    error: models_postbyorgbyrepowebhooksop.PostByOrgByRepoWebhooksBadRequestError


@dataclass(unsafe_hash=True)
class PostByOrgByRepoWebhooksBadRequestError(MesaError):
    r"""Invalid request"""

    data: PostByOrgByRepoWebhooksBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgByRepoWebhooksBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from mesa_sdk import errors, models, utils
from mesa_sdk._hooks import HookContext
from mesa_sdk.types import OptionalNullable, UNSET
from mesa_sdk.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional


class Admin(BaseSDK):
    def create_api_key(
        self,
        *,
        org: str,
        name: Optional[str] = None,
        scopes: Optional[List[models.Scope]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PostByOrgAPIKeysResponse:
        r"""Create API key

        Create a new API key for programmatic access

        :param org:
        :param name:
        :param scopes:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostByOrgAPIKeysRequest(
            org=org,
            body=models.PostByOrgAPIKeysRequestBody(
                name=name,
                scopes=scopes,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/{org}/api-keys",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                True,
                "json",
                Optional[models.PostByOrgAPIKeysRequestBody],
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="postByOrgApiKeys",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return unmarshal_json_response(models.PostByOrgAPIKeysResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysBadRequestErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysUnauthorizedErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysForbiddenErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysNotFoundErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysNotAcceptableErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysConflictErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysInternalServerErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def create_api_key_async(
        self,
        *,
        org: str,
        name: Optional[str] = None,
        scopes: Optional[List[models.Scope]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PostByOrgAPIKeysResponse:
        r"""Create API key

        Create a new API key for programmatic access

        :param org:
        :param name:
        :param scopes:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostByOrgAPIKeysRequest(
            org=org,
            body=models.PostByOrgAPIKeysRequestBody(
                name=name,
                scopes=scopes,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/{org}/api-keys",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                True,
                "json",
                Optional[models.PostByOrgAPIKeysRequestBody],
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="postByOrgApiKeys",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return unmarshal_json_response(models.PostByOrgAPIKeysResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysBadRequestErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysUnauthorizedErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysForbiddenErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysNotFoundErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysNotAcceptableErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysConflictErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysInternalServerErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    def list_api_keys(
        self,
        *,
        org: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetByOrgAPIKeysResponse:
        r"""List API keys

        List all API keys for the organization (key values are not returned)

        :param org:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgAPIKeysRequest(
            org=org,
        )

        req = self._build_request(
            method="GET",
            path="/{org}/api-keys",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgApiKeys",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.GetByOrgAPIKeysResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysBadRequestErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysForbiddenErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysNotFoundErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysConflictErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysInternalServerErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def list_api_keys_async(
        self,
        *,
        org: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetByOrgAPIKeysResponse:
        r"""List API keys

        List all API keys for the organization (key values are not returned)

        :param org:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgAPIKeysRequest(
            org=org,
        )

        req = self._build_request_async(
            method="GET",
            path="/{org}/api-keys",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgApiKeys",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.GetByOrgAPIKeysResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysBadRequestErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysForbiddenErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysNotFoundErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysConflictErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysInternalServerErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    def revoke_api_key(
        self,
        *,
        id: str,
        org: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DeleteByOrgAPIKeysByIDResponse:
        r"""Revoke API key

        Revoke an API key by its ID

        :param id:
        :param org:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteByOrgAPIKeysByIDRequest(
            id=id,
            org=org,
        )

        req = self._build_request(
            method="DELETE",
            path="/{org}/api-keys/{id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="deleteByOrgApiKeysById",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.DeleteByOrgAPIKeysByIDResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDBadRequestErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDUnauthorizedErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDForbiddenErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDNotFoundErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDNotAcceptableErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDConflictErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDInternalServerErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def revoke_api_key_async(
        self,
        *,
        id: str,
        org: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DeleteByOrgAPIKeysByIDResponse:
        r"""Revoke API key

        Revoke an API key by its ID

        :param id:
        :param org:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteByOrgAPIKeysByIDRequest(
            id=id,
            org=org,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/{org}/api-keys/{id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="deleteByOrgApiKeysById",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.DeleteByOrgAPIKeysByIDResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDBadRequestErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDUnauthorizedErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDForbiddenErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDNotFoundErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDNotAcceptableErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDConflictErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDInternalServerErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from mesa_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from mesa_sdk.utils import (
    FieldMetadata,
    PathParamMetadata,
    RequestMetadata,
    validate_const,
)
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


PostByOrgReposResolutionStrategyRequest = Literal["none",]
r"""Conflict resolution strategy. \"none\" means sync will fail on conflicts."""


class PostByOrgReposAutosyncPollRequestTypedDict(TypedDict):
    period: int
    r"""Polling period in seconds (60s to 24.8d)"""
    type: Literal["poll"]
    resolution_strategy: NotRequired[PostByOrgReposResolutionStrategyRequest]
    r"""Conflict resolution strategy. \"none\" means sync will fail on conflicts."""


class PostByOrgReposAutosyncPollRequest(BaseModel):
    period: int
    r"""Polling period in seconds (60s to 24.8d)"""

    type: Annotated[
        Annotated[Literal["poll"], AfterValidator(validate_const("poll"))],
        pydantic.Field(alias="type"),
    ] = "poll"

    resolution_strategy: Optional[PostByOrgReposResolutionStrategyRequest] = "none"
    r"""Conflict resolution strategy. \"none\" means sync will fail on conflicts."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["resolution_strategy"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


PostByOrgReposAutosyncUnionTypedDict = PostByOrgReposAutosyncPollRequestTypedDict
r"""Optionally enable automatic sync from the upstream repository"""


PostByOrgReposAutosyncUnion = PostByOrgReposAutosyncPollRequest
r"""Optionally enable automatic sync from the upstream repository"""


class PostByOrgReposUpstreamRequestTypedDict(TypedDict):
    uri: str
    r"""URL of the upstream repository"""
    autosync: NotRequired[PostByOrgReposAutosyncUnionTypedDict]
    r"""Optionally enable automatic sync from the upstream repository"""


class PostByOrgReposUpstreamRequest(BaseModel):
    uri: str
    r"""URL of the upstream repository"""

    autosync: Optional[PostByOrgReposAutosyncUnion] = None
    r"""Optionally enable automatic sync from the upstream repository"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["autosync"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgReposRequestBodyTypedDict(TypedDict):
    name: str
    default_branch: NotRequired[str]
    upstream: NotRequired[PostByOrgReposUpstreamRequestTypedDict]


class PostByOrgReposRequestBody(BaseModel):
    name: str

    default_branch: Optional[str] = "main"

    upstream: Optional[PostByOrgReposUpstreamRequest] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["default_branch", "upstream"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgReposRequestTypedDict(TypedDict):
    org: str
    body: NotRequired[PostByOrgReposRequestBodyTypedDict]


class PostByOrgReposRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    body: Annotated[
        Optional[PostByOrgReposRequestBody],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["body"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgReposInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgReposInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgReposConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgReposConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgReposNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgReposNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgReposNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgReposNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgReposForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgReposForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgReposUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgReposUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgReposBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgReposBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


PostByOrgReposResolutionStrategyResponse = Literal["none",]
r"""Conflict resolution strategy. \"none\" means sync will fail on conflicts."""


class PostByOrgReposAutosyncResponseTypedDict(TypedDict):
    period: float
    r"""Polling period in seconds"""
    resolution_strategy: PostByOrgReposResolutionStrategyResponse
    r"""Conflict resolution strategy. \"none\" means sync will fail on conflicts."""
    type: Literal["poll"]


class PostByOrgReposAutosyncResponse(BaseModel):
    period: float
    r"""Polling period in seconds"""

    resolution_strategy: PostByOrgReposResolutionStrategyResponse
    r"""Conflict resolution strategy. \"none\" means sync will fail on conflicts."""

    type: Annotated[
        Annotated[Literal["poll"], AfterValidator(validate_const("poll"))],
        pydantic.Field(alias="type"),
    ] = "poll"


class PostByOrgReposUpstreamResponseTypedDict(TypedDict):
    uri: str
    r"""URL of the upstream repository"""
    autosync: Nullable[PostByOrgReposAutosyncResponseTypedDict]
    r"""Automatic sync configuration, if enabled"""
    last_sync_attempt: Nullable[datetime]
    r"""Timestamp of the last sync attempt"""
    last_sync_success: Nullable[datetime]
    r"""Timestamp of the last successful sync"""
    last_sync_error: Nullable[str]
    r"""Error message from the last failed sync attempt"""


class PostByOrgReposUpstreamResponse(BaseModel):
    uri: str
    r"""URL of the upstream repository"""

    autosync: Nullable[PostByOrgReposAutosyncResponse]
    r"""Automatic sync configuration, if enabled"""

    last_sync_attempt: Nullable[datetime]
    r"""Timestamp of the last sync attempt"""

    last_sync_success: Nullable[datetime]
    r"""Timestamp of the last successful sync"""

    last_sync_error: Nullable[str]
    r"""Error message from the last failed sync attempt"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class PostByOrgReposResponseTypedDict(TypedDict):
    r"""Repository created"""

    id: str
    org: str
    name: str
    default_branch: str
    size_bytes: float
    last_push_at: Nullable[str]
    created_at: str
    upstream: Nullable[PostByOrgReposUpstreamResponseTypedDict]
    r"""Optionally add an upstream repository. You can configure automatic syncing from the upstream repository."""


class PostByOrgReposResponse(BaseModel):
    r"""Repository created"""

    id: str

    org: str

    name: str

    default_branch: str

    size_bytes: float

    last_push_at: Nullable[str]

    created_at: str

    upstream: Nullable[PostByOrgReposUpstreamResponse]
    r"""Optionally add an upstream repository. You can configure automatic syncing from the upstream repository."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import getbyorgop as models_getbyorgop
from mesa_sdk.types import BaseModel
from typing import Optional


class GetByOrgInternalServerErrorData(BaseModel):
    error: models_getbyorgop.GetByOrgInternalServerErrorError


@dataclass(unsafe_hash=True)
class GetByOrgInternalServerError(MesaError):
    r"""Internal error"""

    data: GetByOrgInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgConflictErrorData(BaseModel):
    error: models_getbyorgop.GetByOrgConflictError


@dataclass(unsafe_hash=True)
class GetByOrgConflictError(MesaError):
    r"""Conflict"""

    data: GetByOrgConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgNotAcceptableErrorData(BaseModel):
    error: models_getbyorgop.GetByOrgNotAcceptableError


@dataclass(unsafe_hash=True)
class GetByOrgNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: GetByOrgNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgNotFoundErrorData(BaseModel):
    error: models_getbyorgop.GetByOrgNotFoundError


@dataclass(unsafe_hash=True)
class GetByOrgNotFoundError(MesaError):
    r"""Not found"""

    data: GetByOrgNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgForbiddenErrorData(BaseModel):
    error: models_getbyorgop.GetByOrgForbiddenError


@dataclass(unsafe_hash=True)
class GetByOrgForbiddenError(MesaError):
    r"""Forbidden"""

    data: GetByOrgForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgUnauthorizedErrorData(BaseModel):
    error: models_getbyorgop.GetByOrgUnauthorizedError


@dataclass(unsafe_hash=True)
class GetByOrgUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: GetByOrgUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgBadRequestErrorData(BaseModel):
    error: models_getbyorgop.GetByOrgBadRequestError


@dataclass(unsafe_hash=True)
class GetByOrgBadRequestError(MesaError):
    r"""Invalid request"""

    data: GetByOrgBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
